==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/OperatorSelectorOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorOpeningEventArgsDescription } from "./OperatorSelectorOpeningEventArgsDescription";
/**
 * @hidden
 */
export let OperatorSelectorOpeningEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperatorSelectorOpeningEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OperatorSelectorOpeningEventArgsDescriptionMetadata.a == null) {
                OperatorSelectorOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperatorSelectorOpeningEventArgsDescriptionMetadata.c(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
            }
            if (a.j(OperatorSelectorOpeningEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OperatorSelectorOpeningEventArgsDescriptionMetadata.b(a);
            a.aa("OperatorSelectorOpeningEventArgs", () => new OperatorSelectorOpeningEventArgsDescription());
            a.z("OperatorSelectorOpeningEventArgs", OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
    }
    OperatorSelectorOpeningEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OperatorSelectorOpeningEventArgsDescriptionMetadata, 'OperatorSelectorOpeningEventArgsDescriptionMetadata');
    OperatorSelectorOpeningEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorOpeningEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OperatorSelectorOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorOpeningEventArgsDescription } from "./OperatorSelectorOpeningEventArgsDescription";
/**
 * @hidden
 */
export let OperatorSelectorOpeningEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OperatorSelectorOpeningEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OperatorSelectorOpeningEventArgsDescriptionMetadata.a == null) {
                OperatorSelectorOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OperatorSelectorOpeningEventArgsDescriptionMetadata.c(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
            }
            if (a.k(OperatorSelectorOpeningEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OperatorSelectorOpeningEventArgsDescriptionMetadata.b(a);
            a.ac("OperatorSelectorOpeningEventArgs", () => new OperatorSelectorOpeningEventArgsDescription());
            a.ab("OperatorSelectorOpeningEventArgs", OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
    }
    OperatorSelectorOpeningEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OperatorSelectorOpeningEventArgsDescriptionMetadata, 'OperatorSelectorOpeningEventArgsDescriptionMetadata');
    OperatorSelectorOpeningEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorOpeningEventArgsDescriptionMetadata;
})();
